==> joey-gen-1.0.0-src.zip: joey-gen-1.0.0/src/java/org/asyrinx/joey/gen/model/rdb/Index.java <==
/*
 * joey-gen and its relative products are published under the terms
 * of the Apache Software License.
 * 
 * Created on 2004/08/10 17:15:16
 */
package org.asyrinx.joey.gen.model.rdb;

import org.asyrinx.joey.gen.model.ElementSet;

/**
 * @author akima
 */
public class Index extends ElementSet {

    /**
     *  
     */
    public Index() {
        super((String) null);
    }

    /**
     *  
     */
    public Index(Table parent) {
        super(parent, null);
    }

    /**
     *  
     */
    public Index(Table parent, String name) {
        super(parent, name);
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.asyrinx.joey.gen.model.ElementSet#isEntity()
     */
    public boolean isEntity() {
        return true;
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.asyrinx.joey.gen.model.ElementSet#add(org.asyrinx.joey.gen.model.Element)
     */
    public void add(IndexEntry entry) {
        super.add(entry);
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.asyrinx.joey.gen.model.ElementSet#contains(org.asyrinx.joey.gen.model.Element)
     */
    public boolean contains(IndexEntry entry) {
        return super.contains(entry);
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.asyrinx.joey.gen.model.ElementSet#getElement(int)
     */
    public IndexEntry getEntry(int index) {
        return (IndexEntry) super.getElement(index);
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.asyrinx.joey.gen.model.ElementSet#get(java.lang.String)
     */
    public IndexEntry getEntry(String name) {
        return (IndexEntry) super.getElement(name);
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.asyrinx.joey.gen.model.ElementSet#remove(java.lang.String)
     */
    public IndexEntry removeEntry(String name) {
        return (IndexEntry) super.removeElement(name);
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.asyrinx.joey.gen.model.Element#getParentElement()
     */
    public Table getParent() {
        return (Table) super.getParentElement();
    }

    private boolean unique = false;

    /**
     * @return Returns the unique.
     */
    public boolean isUnique() {
        return unique;
    }

    /**
     * @param unique
     *               The unique to set.
     */
    public void setUnique(boolean unique) {
        this.unique = unique;
    }
}

==> joey-gen-1.1.1-src.zip: joey-gen-1.1.1/src/java/org/asyrinx/joey/gen/model/rdb/Index.java <==
/*
 * joey-gen and its relative products are published under the terms
 * of the Apache Software License.
 * 
 * Created on 2004/08/10 17:15:16
 */
package org.asyrinx.joey.gen.model.rdb;

import org.apache.commons.lang.builder.EqualsBuilder;
import org.asyrinx.joey.gen.model.ElementSet;

/**
 * @author akima
 */
public class Index extends ElementSet {

    /**
     *  
     */
    public Index() {
        super((String) null);
    }

    /**
     *  
     */
    public Index(Table parent) {
        super(parent, null);
    }

    /**
     *  
     */
    public Index(Table parent, String name) {
        super(parent, name);
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.asyrinx.joey.gen.model.ElementSet#isEntity()
     */
    public boolean isEntity() {
        return true;
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.asyrinx.joey.gen.model.ElementSet#add(org.asyrinx.joey.gen.model.Element)
     */
    public void add(IndexEntry entry) {
        super.add(entry);
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.asyrinx.joey.gen.model.ElementSet#contains(org.asyrinx.joey.gen.model.Element)
     */
    public boolean contains(IndexEntry entry) {
        return super.contains(entry);
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.asyrinx.joey.gen.model.ElementSet#getElement(int)
     */
    public IndexEntry getEntry(int index) {
        return (IndexEntry) super.getElement(index);
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.asyrinx.joey.gen.model.ElementSet#get(java.lang.String)
     */
    public IndexEntry getEntry(String name) {
        return (IndexEntry) super.getElement(name);
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.asyrinx.joey.gen.model.ElementSet#remove(java.lang.String)
     */
    public IndexEntry removeEntry(String name) {
        return (IndexEntry) super.removeElement(name);
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.asyrinx.joey.gen.model.Element#getParentElement()
     */
    public Table getParent() {
        return (Table) super.getParentElement();
    }

    private boolean unique = false;

    /**
     * @return Returns the unique.
     */
    public boolean isUnique() {
        return unique;
    }

    /**
     * @param unique
     *            The unique to set.
     */
    public void setUnique(boolean unique) {
        this.unique = unique;
    }

    /*
     * (non-Javadoc)
     * 
     * @see java.lang.Object#equals(java.lang.Object)
     */
    public boolean equals(Object obj) {
        if (!super.equals(obj))
            return false;
        if (!(obj instanceof Index))
            return false;
        final Index other = (Index) obj;
        return new EqualsBuilder() //
                .append(this.isUnique(), other.isUnique()) //
                .isEquals();
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.asyrinx.joey.gen.model.ElementSet#careChildOrder()
     */
    public boolean careChildOrder() {
        return true;
    }
}
